/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

cpiai.txt - from BLS - ftp://ftp.bls.gov/pub/special.requests/cpi/cpiai.txt
 
gsp_naics_all_C.csv - from BEA - http://www.bea.gov/regional/downloadzip.cfm

gsp_sic_all_C.csv - from BEA - http://www.bea.gov/regional/downloadzip.cfm

Note: From the BEA link, download the NAICS GDP and SIC GDP .zip files and extract these two.csv files.

la.data.2.AllStatesU.txt - from BLS - ftp://ftp.bls.gov/pub/time.series/la/la.data.2.AllStatesU

Note: From the BLS link, download and save as la.data.2.AllStatesU.txt


*/

*-----------------------------------*
* PREPARE PANEL OF STATE COVARIATES *
*-----------------------------------*

*****
*     Panel of State Covariates:
*     1. State annual population
*     2. Share of population aged 15-59 
*     3. State annual real gross state product per capita
*     4. State monthly unemployment rate
*****

* 1-2. State population and share aged 15-59

* Note that the Census Bureau has a different format for each decade of historical population estimates,
* so each decade is coded separately and then gets appended together.

* 1970 - 1979 :

insheet using "http://www.census.gov/popest/data/state/asrh/pre-1980/tables/PE-19.csv" , clear delimit(",")

drop in 1/6 // Remove header rows

rename v1 year
rename v2 statefips
destring year statefips , force replace

quietly forv a = 5/22 {
replace v`a' = subinstr(v`a' , "," , "" , . ) // Remove commas
destring v`a' , force replace                 // Convert to numeric storage
}

egen age1559 = rsum(v8-v16)
egen popall = rsum(v5-v22)

collapse (sum) popall age1559 , by(statefips year) // Convert to state year panel

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"

keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559
sort statefips year

compress
save population_state_annual , replace // Each decade will be subsequently appended to this file

******
* 1980 - 1989 :

infix str temp 1-1000 using "http://www.census.gov/popest/data/state/asrh/1980s/tables/s5yr8090.txt", clear

drop in 1/10 // Remove header rows

gen statefips = .
order statefips temp

replace statefips = 1 if temp[_n-1] == "Alabama"
replace statefips = 2 if temp[_n-1] == "Alaska"
replace statefips = 4 if temp[_n-1] == "Arizona"
replace statefips = 5 if temp[_n-1] == "Arkansas"
replace statefips = 6 if temp[_n-1] == "California"
replace statefips = 8 if temp[_n-1] == "Colorado"
replace statefips = 9 if temp[_n-1] == "Connecticut"
replace statefips = 10 if temp[_n-1] == "Delaware"
replace statefips = 11 if temp[_n-1] == "District of Columbia"
replace statefips = 12 if temp[_n-1] == "Florida"
replace statefips = 13 if temp[_n-1] == "Georgia"
replace statefips = 15 if temp[_n-1] == "Hawaii"
replace statefips = 16 if temp[_n-1] == "Idaho"
replace statefips = 17 if temp[_n-1] == "Illinois"
replace statefips = 18 if temp[_n-1] == "Indiana"
replace statefips = 19 if temp[_n-1] == "Iowa"
replace statefips = 20 if temp[_n-1] == "Kansas"
replace statefips = 21 if temp[_n-1] == "Kentucky"
replace statefips = 22 if temp[_n-1] == "Louisiana"
replace statefips = 23 if temp[_n-1] == "Maine"
replace statefips = 24 if temp[_n-1] == "Maryland"
replace statefips = 25 if temp[_n-1] == "Massachusetts"
replace statefips = 26 if temp[_n-1] == "Michigan"
replace statefips = 27 if temp[_n-1] == "Minnesota"
replace statefips = 28 if temp[_n-1] == "Mississippi"
replace statefips = 29 if temp[_n-1] == "Missouri"
replace statefips = 30 if temp[_n-1] == "Montana"
replace statefips = 31 if temp[_n-1] == "Nebraska"
replace statefips = 32 if temp[_n-1] == "Nevada"
replace statefips = 33 if temp[_n-1] == "New Hampshire"
replace statefips = 34 if temp[_n-1] == "New Jersey"
replace statefips = 35 if temp[_n-1] == "New Mexico"
replace statefips = 36 if temp[_n-1] == "New York"
replace statefips = 37 if temp[_n-1] == "North Carolina"
replace statefips = 38 if temp[_n-1] == "North Dakota"
replace statefips = 39 if temp[_n-1] == "Ohio"
replace statefips = 40 if temp[_n-1] == "Oklahoma"
replace statefips = 41 if temp[_n-1] == "Oregon"
replace statefips = 42 if temp[_n-1] == "Pennsylvania"
replace statefips = 44 if temp[_n-1] == "Rhode Island"
replace statefips = 45 if temp[_n-1] == "South Carolina"
replace statefips = 46 if temp[_n-1] == "South Dakota"
replace statefips = 47 if temp[_n-1] == "Tennessee"
replace statefips = 48 if temp[_n-1] == "Texas"
replace statefips = 49 if temp[_n-1] == "Utah"
replace statefips = 50 if temp[_n-1] == "Vermont"
replace statefips = 51 if temp[_n-1] == "Virginia"
replace statefips = 53 if temp[_n-1] == "Washington"
replace statefips = 54 if temp[_n-1] == "West Virginia"
replace statefips = 55 if temp[_n-1] == "Wisconsin"
replace statefips = 56 if temp[_n-1] == "Wyoming"

replace statefips = statefips[_n-1] if statefips == .

gen year1990 = substr(temp,   -9, 9)
gen year1989 = substr(temp,  -18, 9)
gen year1988 = substr(temp,  -27, 9)
gen year1987 = substr(temp,  -36, 9)
gen year1986 = substr(temp,  -45, 9)
gen year1985 = substr(temp,  -54, 9)
gen year1984 = substr(temp,  -63, 9)
gen year1983 = substr(temp,  -72, 9)
gen year1982 = substr(temp,  -81, 9)
gen year1981 = substr(temp,  -90, 9)
gen year1980 = substr(temp,  -99, 9)

gen age = .

replace age = 999 if substr(temp,1,5) == "Total"
replace age = 0 if age[_n-1] == 999
forv y = 1/17 {
replace age = 5 * `y' if age[_n-1] == (`y' - 1) * 5
}

drop if age == . | age < 15
drop if age > 59 & age < 999
drop temp

destring year* , force replace

quietly forv y = 1980/1990 {

gen temp = year`y' if age >= 15 & age <= 59
egen age1559`y' = sum(temp) , by(statefips)
drop temp
gen temp = year`y' if age == 999
egen popall`y' = max(temp) , by(statefips)
drop temp year`y'
}

drop age
duplicates drop

reshape long age1559 popall , i(statefips) j(year) // Convert to state year panel

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"

keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559

append using population_state_annual // Append the 1970-1979 data

sort statefips year
drop if year == 1990

compress
save population_state_annual , replace // Each decade will be subsequently appended to this file

******
* 1990 - 1999 :

infix str temp 1-1000 using "http://www.census.gov/popest/data/state/asrh/1990s/tables/ST-99-08.txt", clear

drop in 1/865 // Remove header and National totals rows

gen statefips = .
order statefips temp

replace statefips = 1 if temp[_n-1] == "Alabama"
replace statefips = 2 if temp[_n-1] == "Alaska"
replace statefips = 4 if temp[_n-1] == "Arizona"
replace statefips = 5 if temp[_n-1] == "Arkansas"
replace statefips = 6 if temp[_n-1] == "California"
replace statefips = 8 if temp[_n-1] == "Colorado"
replace statefips = 9 if temp[_n-1] == "Connecticut"
replace statefips = 10 if temp[_n-1] == "Delaware"
replace statefips = 11 if temp[_n-1] == "District of Columbia"
replace statefips = 12 if temp[_n-1] == "Florida"
replace statefips = 13 if temp[_n-1] == "Georgia"
replace statefips = 15 if temp[_n-1] == "Hawaii"
replace statefips = 16 if temp[_n-1] == "Idaho"
replace statefips = 17 if temp[_n-1] == "Illinois"
replace statefips = 18 if temp[_n-1] == "Indiana"
replace statefips = 19 if temp[_n-1] == "Iowa"
replace statefips = 20 if temp[_n-1] == "Kansas"
replace statefips = 21 if temp[_n-1] == "Kentucky"
replace statefips = 22 if temp[_n-1] == "Louisiana"
replace statefips = 23 if temp[_n-1] == "Maine"
replace statefips = 24 if temp[_n-1] == "Maryland"
replace statefips = 25 if temp[_n-1] == "Massachusetts"
replace statefips = 26 if temp[_n-1] == "Michigan"
replace statefips = 27 if temp[_n-1] == "Minnesota"
replace statefips = 28 if temp[_n-1] == "Mississippi"
replace statefips = 29 if temp[_n-1] == "Missouri"
replace statefips = 30 if temp[_n-1] == "Montana"
replace statefips = 31 if temp[_n-1] == "Nebraska"
replace statefips = 32 if temp[_n-1] == "Nevada"
replace statefips = 33 if temp[_n-1] == "New Hampshire"
replace statefips = 34 if temp[_n-1] == "New Jersey"
replace statefips = 35 if temp[_n-1] == "New Mexico"
replace statefips = 36 if temp[_n-1] == "New York"
replace statefips = 37 if temp[_n-1] == "North Carolina"
replace statefips = 38 if temp[_n-1] == "North Dakota"
replace statefips = 39 if temp[_n-1] == "Ohio"
replace statefips = 40 if temp[_n-1] == "Oklahoma"
replace statefips = 41 if temp[_n-1] == "Oregon"
replace statefips = 42 if temp[_n-1] == "Pennsylvania"
replace statefips = 44 if temp[_n-1] == "Rhode Island"
replace statefips = 45 if temp[_n-1] == "South Carolina"
replace statefips = 46 if temp[_n-1] == "South Dakota"
replace statefips = 47 if temp[_n-1] == "Tennessee"
replace statefips = 48 if temp[_n-1] == "Texas"
replace statefips = 49 if temp[_n-1] == "Utah"
replace statefips = 50 if temp[_n-1] == "Vermont"
replace statefips = 51 if temp[_n-1] == "Virginia"
replace statefips = 53 if temp[_n-1] == "Washington"
replace statefips = 54 if temp[_n-1] == "West Virginia"
replace statefips = 55 if temp[_n-1] == "Wisconsin"
replace statefips = 56 if temp[_n-1] == "Wyoming"

replace statefips = statefips[_n-1] if statefips == .

gen year1990 = substr(temp,   -20, 10)
gen year1991 = substr(temp,  -30, 10)
gen year1992 = substr(temp,  -40, 10)
gen year1993 = substr(temp,  -50, 10)
gen year1994 = substr(temp,  -60, 10)
gen year1995 = substr(temp,  -70, 10)
gen year1996 = substr(temp,  -80, 10)
gen year1997 = substr(temp,  -90, 10)
gen year1998 = substr(temp,  -100, 10)
gen year1999 = substr(temp,  -110, 10)

gen age = .

replace age = 999 if substr(temp,1,5) == "Total"
replace age = 0 if age[_n-1] == 999
forv y = 1/17 {
replace age = 5 * `y' if age[_n-1] == (`y' - 1) * 5
}

drop if age == . | age < 15
drop if age > 59 & age < 999
drop temp

destring year* , force replace

quietly forv y = 1990/1999 {

gen temp = year`y' if age >= 15 & age <= 59
egen age1559`y' = sum(temp) , by(statefips)
drop temp
gen temp = year`y' if age == 999
egen popall`y' = max(temp) , by(statefips)
drop temp year`y'
}

drop age
duplicates drop

reshape long age1559 popall , i(statefips) j(year) // Convert to state year panel

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"

keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559

append using population_state_annual // Append the 1970-1989 data

sort statefips year

compress
save population_state_annual , replace // Each decade will be subsequently appended to this file

******
* 2000 - 2009 :

quietly foreach s in 1 2 4 5 6 8 9 { // These must be done separately by each state

insheet using "http://www.census.gov/popest/data/intercensal/state/tables/ST-EST00INT-02/ST-EST00INT-02-0`s'.csv" , clear delimit(",")

keep v1 v3-v12

keep in 5/23 // Remove header rows and rows disaggregated by sex

quietly forv v = 3/12 {
local year = `v' + 1997
rename v`v' year`year'
replace year`year' = subinstr(year`year' , "," ,"", . )
destring year`year' , force replace
}

gen age = 999 if v1 == "BOTH SEXES"
replace age = 0 if v1 == ".Under 5 years"
drop v1

quietly forv y = 1/17 {
replace age = 5 * `y' if age[_n-1] == (`y' - 1) * 5
}

quietly forv y = 2000/2009 {
gen temp = year`y' if age == 999
egen popall`y' = max(temp)
drop temp
gen temp = year`y' if age >= 15 & age <= 59
egen age1559`y' = sum(temp)
drop temp
drop year`y'
}

drop age
duplicates drop

gen statefips = `s'

reshape long age1559 popall , i(statefips) j(year) // Convert to state year panel

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"


keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559

append using population_state_annual // Append the 1970-1999 data

sort statefips year

compress
save population_state_annual , replace // Each decade will be subsequently appended to this file

}

**

quietly foreach s in 10 11 12 13 15 16 17 18 19 20 21 22 23 24 25 /// These must be done separately by each state
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 44 45 46 47 48 49 50 51 53 54 55 56 {

insheet using "http://www.census.gov/popest/data/intercensal/state/tables/ST-EST00INT-02/ST-EST00INT-02-`s'.csv" , clear delimit(",")

keep v1 v3-v12

keep in 5/23 // Remove header rows and rows disaggregated by sex

quietly forv v = 3/12 {
local year = `v' + 1997
rename v`v' year`year'
replace year`year' = subinstr(year`year' , "," ,"", . )
destring year`year' , force replace
}

gen age = 999 if v1 == "BOTH SEXES"
replace age = 0 if v1 == ".Under 5 years"
drop v1

quietly forv y = 1/17 {
replace age = 5 * `y' if age[_n-1] == (`y' - 1) * 5
}

quietly forv y = 2000/2009 {
gen temp = year`y' if age == 999
egen popall`y' = max(temp)
drop temp
gen temp = year`y' if age >= 15 & age <= 59
egen age1559`y' = sum(temp)
drop temp
drop year`y'
}

drop age
duplicates drop

gen statefips = `s'

reshape long age1559 popall , i(statefips) j(year) // Convert to state year panel

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"

keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559

append using population_state_annual // Append the 1970-1999 data

sort statefips year

compress
save population_state_annual , replace // Each decade will be subsequently appended to this file

}

******
* 2010 - 2012 :

clear
set more off
run prepare_data_01_valuelabels.do

insheet using "http://www.census.gov/popest/data/state/asrh/2012/files/SC-EST2012-AGESEX-CIV.csv" , clear delimit(",")

keep if sumlev == 40 & sex == 0

rename state statefips

quietly foreach y in 2010 2011 2012 {
gen temp = popest`y'_civ if age >= 15 & age <= 59
egen age1559`y' = sum(temp) , by(statefips)
drop temp
gen temp = popest`y'_civ if age == 999
egen popall`y' = max(temp) , by(statefips)
drop temp
}

keep statefips age1559* popall*

duplicates drop

reshape long age1559 popall , i(statefips) j(year)

gen share1559 = age1559 / popall
gen lpopall = ln(popall)

label variable popall "Total population count in state in year"
label variable share1559 "Fraction of state population aged 15-59"
label variable lpopall "Log of total population in state in year"

keep statefips year popall lpopall share1559
order statefips year popall lpopall share1559

append using population_state_annual

sort statefips year
label value statefips fips

compress
save population_state_annual , replace

* This is now a full panel of state by year population estimates from 1970-2012


*****
*     Prepare Real GSP / Capita
*****

* NOTE: The BEA doesn't have direct http or ftp links to these files, so you must first manually download
* (and extract the .csv) files of NAICS GDP and SIC GDP from http://www.bea.gov/regional/downloadzip.cfm
* They are also included in this folder.

clear
set more off
run prepare_data_01_valuelabels.do

insheet using "gsp_sic_all_C.csv" , clear delimit(",")

keep if industryid == 1 // All industry total

drop componentid componentname industryid region industryname geoname
drop if fips==0 | fips>56

qui forv v=8/42 {
local w=`v'+1955
rename v`v' gsp`w'
label variable gsp`w' "GSP (millions nominal) in `w'"
destring gsp`w' , force replace
}
drop gsp1997

compress
save gsp_state_annual , replace // Will be appended with NAICS-based data below

**

insheet using "gsp_naics_all_C.csv" , clear

keep if industryid == 101 // All industry total

drop componentid componentname industryid region industryname geoname
drop if fips==0 | fips>56

qui forv v=8/23 {
local w=`v'+1989
rename v`v' gsp`w'
label variable gsp`w' "GSP (millions nominal) in `w'"
destring gsp`w' , force replace
}

merge 1:1 fips using gsp_state_annual // Append the SIC-based data
drop _merge

rename fips statefips

reshape long gsp , i(statefips) j(year)  // Convert to state year panel 

sort statefips year

compress
save gsp_state_annual , replace

* This is now a full panel of state by year GSP from 1970-2012

merge m:1 year using dollars2011_cpiu_annual
keep if _merge == 3 // Drop pre-1976
drop _merge

merge 1:1 statefips year using population_state_annual
keep if _merge == 3  // drop pre-1976
drop _merge lpopall share1559

gen rgsp = gsp * dol2011

gen rgspcap = rgsp / popall * 1000000

gen lrgspcap = ln(rgspcap)

drop popall dol2011

label variable state "State (FIPS code)"
label variable year "Year"
label variable gsp "Gross State Product (millions) nominal"
label variable rgsp "Real Gross State Product (millions)"
label variable rgspcap "Real Gross State Product per capita"
label variable lrgspcap "Log of real GSP per capita"

sort statefips year
label value statefips fips

compress
save gsp_state_annual , replace

* This is now a state by year panel of gross state product from 1970-2012


*****
*     Prepare State monthly unemployment rate
*****

infix str temp 1-100 using la.data.2.AllStatesU.txt , clear

drop in 1 // Header

replace temp = trim(temp)
replace temp = subinstr(temp,"  "," ",.)
replace temp = subinstr(temp,"  "," ",.)
replace temp = subinstr(temp,"  "," ",.)
replace temp = subinstr(temp,"  "," ",.)
replace temp = subinstr(temp,"  "," ",.)
split temp , parse(" ")

drop temp temp5

rename temp1 series_str
rename temp2 year
rename temp3 month
rename temp4 value

gen statefips = substr(series_str, 6, 2)

replace month = subinstr(month, "M", "",.)
destring statefips year month value , force replace

gen series = substr(series_str , -1 , 1)
destring series , force replace
drop series_str
duplicates drop statefips year month series , force // Should drop none

sort statefips year month series
order statefips year month series

foreach val in 3 4 5 6 {
gen temp = value if series == `val'
egen temp`val' = max(temp) , by(year month statefips)
drop temp
gen temp = value if series == `val' & month == 13
egen temp`val'ann = max(temp) , by(year statefips)
drop temp
}

drop if month == 13
drop series value
duplicates drop
duplicates drop statefips year month , force // Should drop none

drop if year == 2013

label values statefips fips

label variable statefips "State (FIPS code)"
label variable year "Year"
label variable month "Month"

rename temp3 unemprt
label variable unemprt "Unemployment rate for state for month"
rename temp3ann annual_unemprt
label variable annual_unemprt "Unemployment rate for state for year"

rename temp4 unem
label variable unem "Unemployment for state for month"
rename temp4ann annual_unem
label variable annual_unem "Unemployment for state for year"

drop temp5 temp5ann // Employment, as reported in CPS -- confusing when merged in with BDS/QCEW/QWI employment data

rename temp6 laborforce
label variable laborforce "Labor force participation count for state for month"
rename temp6ann annual_laborforce 
label variable annual_laborforce "Labor force participation count for state for year"

drop if state == 43 // An unused FIPS code that appears in these BLS data

compress
save unemprt_temp , replace

use unemprt_temp , clear
drop annual*

save unemprt_state_monthly , replace

**

use unemprt_temp , clear
drop annual* unemprt

gen quarter = 1 + floor(month/3.01)

collapse (sum) unem laborforce , by(statefips year quarter)

gen unemprt = round(100 * unem / laborforce , 0.1)

order statefips year quarter unemprt unem laborforce

label variable unemprt "Unemployment rate for state for quarter"
label variable unem "Unemployment for state for quarter"
label variable laborforce "Labor force participation count for state for quarter"

compress
save unemprt_state_quarterly , replace

**

use unemprt_temp , clear
keep statefips year annual*

foreach var in unemprt unem laborforce {
rename annual_`var' `var'
}

duplicates drop

save unemprt_state_annual , replace

erase unemprt_temp.dta // Clean up
