/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

dollars2011_cpiu_quarterly.dta - Quarterly CPI values

mw_state_quarterly.dta - State minimum wage values as of first of each quarter

population_state_annual.dta - Annual state population

gsp_state_annual.dta - Annual gross state product

unemprt_state_quarterly.dta - Quarterly state unemployment rates

QCEW:  multiple, by year; pattern is `year'.q1-q4.singlefile.csv - from BLS - "singlefile" version for each year 1990-2012
NOTE: the BLS recently updated their ftp hosting for the QCEW, so the format of these files may be outdated as we prepared them.

NOTE: See the DataSources.txt file for more information


*/

*--------------------*
*       QCEW         *
*--------------------*

* NOTE: the BLS recently updated their ftp hosting for the QCEW, so the format of these files may be outdated as we prepared them.

* Note: the QCEW is available only in SIC-based versions for pre-1990
* We combine the pre-1990 and 1990-2012 versions for a state panel
* We use only the standardized NAICS 1990-2012 version by industry

* See more documentation on the pre-1990 SIC files here:
* ftp://ftp.bls.gov/pub/special.requests/cew/sic/history/readme.txt

insheet using st751814.csv , clear delimit(",")

save qcew_pre1990 , replace // The later years will be appended to this

insheet using st821874.csv , clear delimit(",")

append using qcew_pre1990

save qcew_pre1990 , replace // The later years will be appended to this

insheet using st881944.csv , clear delimit(",")

append using qcew_pre1990

save qcew_pre1990 , replace

use qcew_pre1990 , clear

rename v1 year
rename v2 quarter
rename v3 state
rename v4 division
rename v5 sic
rename v6 ownership
rename v7 size
rename v8 estabs
rename v9 emp_month1
rename v10 emp_month2
rename v11 emp_month3
rename v12 payroll

drop if year >= 1990
drop if state < 1 | state > 56

  keep if ownership == . // All employment in state (all sectors and ownership)

* keep if ownership == 5 & division == "" // All private sector employment in state - COMMENT OUT TO INCLUDE OTHER SECTORS ALSO

drop division sic ownership size

foreach var in estabs emp_month1 emp_month2 emp_month3 payroll {
replace `var' = . if `var' == 0
* Correct for some missing values for several state years:
* Alaska and D.C. in 1978, 1979, and 1980
}

sort state year quarter

egen emp = rmean(emp_month1 emp_month2 emp_month3)

merge m:1 year quarter using dollars2011_cpiu_quarterly
drop if _merge == 2
drop _merge

replace payroll = payroll * dol2011 / 1000000

gen avgwage = payroll / emp * 1000000

drop dol2011 emp_month1 emp_month2 emp_month3

rename state statefips

label values statefips fips

gen quarterly = yq(year , quarter)

gen industry = 10 // Statewide total

sort state industry quarterly
order statefips industry quarterly year quarter emp estabs payroll avgwage

label variable state "State"
label variable industry "Industry (2-digit NAICS)"
label variable year "Year"
label variable quarter "Quarter"
label variable quarterly "Quarterly indicator (Stata format)"
label variable estabs "Quarterly establishment count"
label variable emp "Quarterly average employment"
label variable payroll "Quarterly total payroll (millions 2011)"
label variable avgwage "Quarterly average wage (dollars 2011)"

compress

save qcew_pre1990 , replace // The 1990-2012 data will be appended to this


***

/* 
Selected aggregation levels:
50,"State, Total Covered"
54,"State, NAICS Sector -- by ownership sector"
55,"State, NAICS 3-digit -- by ownership sector"

Ownership codes:
0,"Total Covered"
1,"Federal Government"
2,"State Government"
3,"Local Government"
4,"International Government"
5,"Private"
8,"Total Government"
9,"Total U.I. Covered (Excludes Federal Government)"
*/


*******************************
program define qcew_industries

* keep if own_code == 5 // All private sector businesses - COMMENT OUT TO INCLUDE OTHER SECTORS ALSO

keep if agglvl_code == 50 | agglvl_code == 54 // 2-digit NAICS (ownership sector)

gen industry = .
replace industry = 10 if industry_code == "10"
replace industry = 11 if industry_code == "11"
replace industry = 21 if industry_code == "21"
replace industry = 22 if industry_code == "22"
replace industry = 23 if industry_code == "23"
replace industry = 31 if industry_code == "31-33"
replace industry = 42 if industry_code == "42"
replace industry = 44 if industry_code == "44-45"
replace industry = 48 if industry_code == "48-49"
replace industry = 51 if industry_code == "51"
replace industry = 52 if industry_code == "52"
replace industry = 53 if industry_code == "53"
replace industry = 54 if industry_code == "54"
replace industry = 55 if industry_code == "55"
replace industry = 56 if industry_code == "56"
replace industry = 61 if industry_code == "61"
replace industry = 62 if industry_code == "62"
replace industry = 71 if industry_code == "71"
replace industry = 72 if industry_code == "72"
replace industry = 81 if industry_code == "81"
replace industry = 92 if industry_code == "92"

drop if industry == .

gen state = substr(area_fips, 1, 2)
destring state , force replace
drop if state > 56 | state < 1

rename qtr quarter
rename qtrly_estabs_count estabs
rename state statefips
rename total_qtrly_wages payroll
rename avg_wkly_wage avgwage

label values statefips fips
label values industry indlab

egen emp = rmean(month1_emplvl month2_emplvl month3_emplvl)

order statefips year quarter industry estabs emp payroll
keep statefips year quarter industry estabs emp payroll

collapse (sum) estabs emp payroll , by(state year quarter industry)
* This is necessary because there are multiple ownership codes (e.g. private, various government)

sort state year quarter industry

merge m:1 year quarter using dollars2011_cpiu_quarterly
drop if _merge == 2
drop _merge

replace payroll = payroll * dol2011 / 1000000

gen avgwage = payroll / emp * 1000000

drop dol2011

gen quarterly = yq(year , quarter)

sort state industry quarterly
order statefips industry quarterly year quarter emp estabs payroll avgwage

label variable state "State"
label variable industry "Industry (2-digit NAICS)"
label variable year "Year"
label variable quarter "Quarter"
label variable quarterly "Quarterly indicator (Stata format)"
label variable estabs "Quarterly establishment count"
label variable emp "Quarterly average employment"
label variable payroll "Quarterly total payroll (millions 2011)"
label variable avgwage "Quarterly average wage (dollars 2011)"


compress

end
*******************************

insheet using 1990.q1-q4.singlefile.csv , clear delimit(",")
quietly qcew_industries
save qcew_industries , replace

display "1990 complete"

forv y = 1991/2012 {
* NOTE: This takes roughly 15GB of RAM if you don't make any restriction on agglvl (industry)
insheet using `y'.q1-q4.singlefile.csv , clear delimit(",")
quietly qcew_industries
append using qcew_industries
save qcew_industries , replace
display "`y' complete"
}

****

use qcew_industries , clear


/* If using private sector employment only, rather than all employment
   Note that there is a line above in the program qcew_industries that must also be un-commented

foreach var in emp estabs payroll {
egen tot`var' = sum(`var') , by(state quarterly)
}
gen twage = avgwage * emp
egen totwage = sum(twage) , by(state quarterly)
gen totavgwage = totwage / totemp

drop emp estabs payroll avgwage twage totwage
duplicates drop statefips quarterly , force
replace industry = 10

foreach var in emp estabs payroll avgwage {
rename tot`var' `var'
}

append using qcew_industries

*/



append using qcew_pre1990 // Append the pre-1990 QCEW data

merge m:1 state year quarter using mw_state_quarterly
drop _merge

merge m:1 statefips year using population_state_annual
keep if _merge == 3
drop _merge

merge m:1 statefips year using gsp_state_annual
keep if _merge == 3
drop _merge

merge m:1 statefips year quarter using unemprt_state_quarterly
drop _merge

* Note: the BLS doesn't report state unemployment monthly for 1975, so
* the merge is effective only for observations 1976-2012

sort statefips industry quarterly

egen stindgp = group(statefips industry)
order stindgp
label variable stindgp "State X Industry group identifier"

xtset stindgp quarterly

gen lemp = ln(emp)
label variable lemp "Log of quarterly employment"

gen jgr = (emp - l.emp) / (0.5 * l.emp + 0.5 * emp)
label variable jgr "Net quarterly job growth rate"

gen lavgwage = ln(avgwage)
label variable lavgwage "Log of quarterly average wage (dollars 2011)"

order stindgp statefips censusreg censusdiv industry quarterly year quarter emp lemp ///
jgr lnmin realmw mw realfedmw fedmw indexedwage eversuperfed payroll avgwage lavgwage ///
popall lpopall share1559 gsp rgsp rgspcap lrgspcap unemprt unem laborforce

compress
save qcew , replace

erase qcew_industries.dta // Clean up
erase qcew_pre1990.dta // Clean up
